### Name: cvmts.pval
### Title: Computing Exact P-value for Cramer-von Mises Two Sample Tests
### Aliases: cvmts.pval
### Keywords: nonparametric

### ** Examples


## sample size of the first sample
n <- 10

## create a sample x of size n from the normal distribution with mean 0 and 
## standard deviation 1
x <- rnorm(n, 0, 1)

## sample size of the second sample
m <- 10

## create a sample y of size m from the normal distribution with mean 1 and
## standard deviation 1
y <- rnorm(m, 1, 1)

## compute the Cramer-von Mises test statistic
 cvm <- cvmts.test(x, y)

## compute the p-value for the test.
 pval <- cvmts.pval(cvm, n, m)

## Now suppose x is a list of samples of the same size (n), and y is a list 
##   of samples of the same size (m),  and you want to test whether each pair
##   (x[i], y[i]) were drawn from the same population, for i = 1, 2, ...

## a bad way to use cvmts.pval()

##   for(i <- 1; i<=length(x); i++){

##      cvm  <- cvmts.test(x[i], y[i])
##      pval <- cvmts.pval(cvm, n, m)
##   }

## Why? In each call to the function cvmts.pval(), in the first step established is 
## the distribution of the Cramer-von Mises test statistics under the 
## assumption that the two sample were drawn from the same population. Then 
## the distribution is used to calculate the p-value. The first step may
## be expensive if the sample sizes n and m are large. 
   
## I prefer the following way

##  initialize   
#    cvms <- seq(1, length(x)) 

##  compute test scores
#   for(i <- 1; i<=length(x); i++){
#     cvms[i] <- cvmts.test(x[i], y[i])
#   }

#   compute p-values
#    pvals <- cvmts.pval(cvms, n, m)



